@@ -282,6 +282,25 @@ def test_load_workspace(server, monkeypatch):
     assert session.name == 'sampleconfig'
 
 
+def test_load_workspace_named_session(server, monkeypatch):
+    # this is an implementation test. Since this testsuite may be ran within
+    # a tmux session by the developer himself, delete the TMUX variable
+    # temporarily.
+    monkeypatch.delenv('TMUX', raising=False)
+    session_file = curjoin("workspacebuilder/two_pane.yaml")
+
+    # open it detached
+    session = load_workspace(
+        session_file,
+        socket_name=server.socket_name,
+        new_session_name='tmuxp-new',
+        detached=True,
+    )
+
+    assert isinstance(session, libtmux.Session)
+    assert session.name == 'tmuxp-new'
+
+
 @pytest.mark.skipif(
     has_lt_version('2.1'), reason='exact session name matches only tmux >= 2.1'
 )
@@ -387,7 +406,14 @@ def test_load_zsh_autotitle_warning(cli_args, tmpdir, monkeypatch):
         assert 'Please set' not in result.output
 
 
-@pytest.mark.parametrize("cli_args", [(['convert', '.']), (['convert', '.tmuxp.yaml'])])
+@pytest.mark.parametrize(
+    "cli_args",
+    [
+        (['convert', '.']),
+        (['convert', '.tmuxp.yaml']),
+        (['convert', '.tmuxp.yaml', '-y']),
+    ],
+)
 def test_convert(cli_args, tmpdir, monkeypatch):
     # create dummy tmuxp yaml so we don't get yelled at
     tmpdir.join('.tmuxp.yaml').write(
@@ -401,7 +427,10 @@ session_name: hello
     with tmpdir.as_cwd():
         runner = CliRunner()
 
-        runner.invoke(cli.cli, cli_args, input='y\ny\n')
+        # If autoconfirm (-y) no need to prompt y
+        input_args = 'y\ny\n' if '-y' not in cli_args else ''
+
+        runner.invoke(cli.cli, cli_args, input=input_args)
         assert tmpdir.join('.tmuxp.json').check()
         assert tmpdir.join('.tmuxp.json').open().read() == json.dumps(
             {'session_name': 'hello'}, indent=2
@@ -491,6 +520,14 @@ def test_import_tmuxinator(cli_args, inputs, tmpdir, monkeypatch):
             ['\n', 'y\n', './la.yaml\n', 'y\n'],
         ),
         (['freeze'], ['\n', 'y\n', './exists.yaml\n', './la.yaml\n', 'y\n']),  # Exists
+        (  # Create a new one
+            ['freeze', 'mysession', '--force'],
+            ['\n', 'y\n', './la.yaml\n', 'y\n']
+        ),
+        (  # Imply current session if not entered
+            ['freeze', '--force'],
+            ['\n', 'y\n', './la.yaml\n', 'y\n'],
+        ),
     ],
 )
 def test_freeze(server, cli_args, inputs, tmpdir, monkeypatch):
@@ -508,6 +545,34 @@ def test_freeze(server, cli_args, inputs, tmpdir, monkeypatch):
         assert tmpdir.join('la.yaml').check()
 
 
+@pytest.mark.parametrize(
+    "cli_args,inputs",
+    [
+        (  # Overwrite
+            ['freeze', 'mysession', '--force'],
+            ['\n', 'y\n', './exists.yaml\n', 'y\n'],
+        ),
+        (  # Imply current session if not entered
+            ['freeze', '--force'],
+            ['\n', 'y\n', './exists.yaml\n', 'y\n']
+        ),
+    ],
+)
+def test_freeze_overwrite(server, cli_args, inputs, tmpdir, monkeypatch):
+    monkeypatch.setenv('HOME', str(tmpdir))
+    tmpdir.join('exists.yaml').ensure()
+
+    server.new_session(session_name='mysession')
+
+    with tmpdir.as_cwd():
+        runner = CliRunner()
+        # Use tmux server (socket name) used in the test
+        cli_args = cli_args + ['-L', server.socket_name]
+        out = runner.invoke(cli.cli, cli_args, input=''.join(inputs))
+        print(out.output)
+        assert tmpdir.join('exists.yaml').check()
+
+
 def test_get_abs_path(tmpdir):
     expect = str(tmpdir)
     with tmpdir.as_cwd():
